@@ -207,4 +207,4 @@ class SlappResponseObject:
 
     @staticmethod
     def placement_is_winning_low_ink(placement: Tuple[int, str, str]):
-        return placement and placement[0] == 1 and (placement[1].startswith("Top Cut") or placement[1].startswith("Alpha"))
+        return placement and placement[0] == 1 and ("Top Cut" in placement[1] or "Alpha" in placement[1])
